#!/bin/sh

# Berkeley Open Infrastructure for Network Computing
# http://boinc.berkeley.edu
# Copyright (C) 2015 University of California
#
# This is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation;
# either version 2.1 of the License, or (at your option) any later version.
#
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU Lesser General Public License for more details.
#
# To view the GNU Lesser General Public License visit
# http://www.gnu.org/copyleft/lesser.html
# or write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
# Script to build PowerPC-specific and Intel-specific config.h files
# for use in building SETI_BOINC.
#
# by Charlie Fenton 9/10/07
# updated for OS 10.4 SDK and SETI@home v7 on 4/9/11
# updated for Xcode 6 and SETI@home v8 on 12/18/15
# Set optimization level to -O3 on 12/24/15
#
## This script requires OS 10.6 or later
#
## If you drag-install Xcode 4.3 or later, you must have opened Xcode 
## and clicked the Install button on the dialog which appears to 
## complete the Xcode installation before running this script.
#
## In Terminal, CD to the seti_boinc directory.
##     cd [path]/seti_boinc/
## then run this script:
##     source [path]/makeseticonfigs.sh path_to_seti_boinc_dir path_to_boinc_dir
#

if [ $# -ne 2 ]; then
     echo "usage sh $0 path_to_seti_boinc_dir path_to_boinc_dir"
     exit
fi

GCCPATH=`xcrun -find gcc`
if [  $? -ne 0 ]; then
    echo "ERROR: can't find gcc compiler"
    return 1
fi

GPPPATH=`xcrun -find g++`
if [  $? -ne 0 ]; then
    echo "ERROR: can't find g++ compiler"
    return 1
fi

MAKEPATH=`xcrun -find make`
if [  $? -ne 0 ]; then
    echo "ERROR: can't find make tool"
    return 1
fi

TOOLSPATH1=${MAKEPATH%/make}

ARPATH=`xcrun -find ar`
if [  $? -ne 0 ]; then
    echo "ERROR: can't find ar tool"
    return 1
fi

TOOLSPATH2=${ARPATH%/ar}

export PATH="${TOOLSPATH1}":"${TOOLSPATH2}":$PATH

SDKPATH=`xcodebuild -version -sdk macosx Path`

echo "  *************************************************"
echo "  *                                               *"
echo "  *        Configuring for i686-apple-darwin      *"
echo "  *                                               *"
echo "  *************************************************"

cd "$1" 
export CC="${GCCPATH}";export CXX="${GPPPATH}"
export LDFLAGS="-Wl,-syslibroot,${SDKPATH},-arch,i386"
export CPPFLAGS="-isysroot ${SDKPATH} -arch i386 -O3 -DMAC_OS_X_VERSION_MAX_ALLOWED=1040 -DMAC_OS_X_VERSION_MIN_REQUIRED=1040"
export CFLAGS="-isysroot ${SDKPATH} -arch i386 -O3 -DMAC_OS_X_VERSION_MAX_ALLOWED=1040 -DMAC_OS_X_VERSION_MIN_REQUIRED=1040"
export SDKROOT="${SDKPATH}"
export MACOSX_DEPLOYMENT_TARGET=10.4

export PROJECTDIR="$1"
export BOINCDIR="$2"
export LIBTOOLIZE="libtoolize"

./_autosetup --host=i686-apple-darwin

if [ $? -ne 0 ]; then
    exit
fi

./configure -C --disable-server --enable-fast-math --enable-sse3 --with-apple-opengl-framework --with-ssl=$2/../openssl-1.0.2e --host=i686-apple-darwin

if [ $? -ne 0 ]; then
    exit
fi

mv ./sah_config.h ./mac_build/config-i386.h


echo "  *************************************************"
echo "  *                                               *"
echo "  *      Configuring for x86_64-apple-darwin     *"
echo "  *                                               *"
echo "  *************************************************"

cd "$1" 
export CC="${GCCPATH}";export CXX="${GPPPATH}"
export LDFLAGS="-Wl,-syslibroot,${SDKPATH},-arch,x86_64"
export CPPFLAGS="-isysroot ${SDKPATH} -arch x86_64 -O3 -DMAC_OS_X_VERSION_MAX_ALLOWED=1050 -DMAC_OS_X_VERSION_MIN_REQUIRED=1050"
export CFLAGS="-isysroot ${SDKPATH} -arch x86_64 -O3 -DMAC_OS_X_VERSION_MAX_ALLOWED=1050 -DMAC_OS_X_VERSION_MIN_REQUIRED=1050"
export SDKROOT="${SDKPATH}"
export MACOSX_DEPLOYMENT_TARGET=10.5


export PROJECTDIR="$1"
export BOINCDIR="$2"
export LIBTOOLIZE="libtoolize"

./_autosetup --host=x86_64-apple-darwin

if [ $? -ne 0 ]; then
    exit
fi

./configure --disable-server --enable-fast-math --enable-sse3 --with-apple-opengl-framework --with-ssl=$2/../openssl-1.0.2e --host=x86_64-apple-darwin

if [ $? -ne 0 ]; then
    exit
fi

mv ./sah_config.h ./mac_build/config-x86_64.h


